pub struct FullNodeHandle {
pub sui_node: SuiNodeHandle,
pub sui_client: SuiClient,
pub rpc_client: HttpClient,
pub grpc_client: Client,
pub grpc_channel: Channel,
pub rpc_url: String,
}Fields
sui_node: SuiNodeHandlesui_client: SuiClient👎Deprecated: use grpc_client
rpc_client: HttpClient👎Deprecated: use grpc_client
grpc_client: Clientgrpc_channel: Channelrpc_url: StringImplementations
Sourceimpl FullNodeHandle
impl FullNodeHandle
pub async fn new(sui_node: SuiNodeHandle, json_rpc_address: SocketAddr) -> Self
Sourcepub async fn connect_channel_with_retry(url: &str) -> Channel
pub async fn connect_channel_with_retry(url: &str) -> Channel
Connect a tonic channel to the given URL with retries.
In the simulator (MSIM), deterministic scheduling can cause gRPC connection handshakes to exceed timeouts on certain seeds. This method retries to ensure test infrastructure setup is robust regardless of seed.
Use TestCluster::grpc_channel() when connecting to the test cluster’s
fullnode. Use this method directly only when connecting to a custom URL
(e.g. a separately-spawned fullnode with different configuration).